@@ -2,9 +2,9 @@
  *
  * GTK Radio
  *
- * Copyright (C) 2014, 2015, 2016, 2017, 2018, 2022, 2023  Aamot Software
+ * Copyright (C) 2014-2024  Aamot Engineering
  *
- * Author: Ole Aamot <ole@gnome.org>
+ * Author: Ole Aamot <ole@aamot.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include <champlain/champlain.h>
 #include <champlain-gtk/champlain-gtk.h>
 #include <clutter-gtk/clutter-gtk.h>
-#include <geocode-glib/geocode-glib.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <string.h>
@@ -117,10 +116,6 @@ mouse_click_cb (ClutterActor *actor, ClutterButtonEvent *event, ChamplainView *v
 {
 	GError **error;
 	gdouble lat, lon;
-	GeocodePlace *place_city, *place_country;
-	GeocodeLocation *location_city;
-	GeocodeLocation *location_country;
-	GeocodeReverse *reverse_city, *reverse_country;
 
 	const char *name, *name_city, *name_country;
 	/* GeocodeForward *fwd; */
@@ -129,17 +124,6 @@ mouse_click_cb (ClutterActor *actor, ClutterButtonEvent *event, ChamplainView *v
 	lon = champlain_view_x_to_longitude (view, event->x);
 	lat = champlain_view_y_to_latitude (view, event->y);
 	/* champlain_view_center_on (CHAMPLAIN_VIEW (view), lat, lon); */
-	location_city = geocode_location_new (lat, lon, GEOCODE_LOCATION_ACCURACY_CITY);
-	location_country = geocode_location_new (lat, lon, GEOCODE_LOCATION_ACCURACY_COUNTRY);
-	reverse_city = geocode_reverse_new_for_location (location_city);
-	reverse_country = geocode_reverse_new_for_location (location_country);
-	place_city = geocode_reverse_resolve (reverse_city, error);
-	place_country = geocode_reverse_resolve (reverse_country, error);
-	name_city = geocode_place_get_town (place_city);
-	name_country = geocode_place_get_country (place_country);
-	if (!g_strcmp0(name_country, "United States of America")) {
-		name_country = geocode_place_get_state (place_country);
-	}
 	marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
 	name = g_strconcat(name_city, ", ", name_country, NULL);
 	champlain_label_set_text (CHAMPLAIN_LABEL (marker), (gchar *)name);
@@ -589,7 +573,7 @@ gtk_radio_window_cb (GtkApplication *app,
 	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(grid));
 	g_signal_connect (window, "destroy", G_CALLBACK(gtk_main_quit), NULL);
 #endif
-	gtk_window_set_title (GTK_WINDOW(window), _("GTK Radio"));
+	gtk_window_set_title (GTK_WINDOW(window), _("GTK Radio 548.0 (www.gtkradio.org)"));
 	gtk_window_set_default_size (GTK_WINDOW(window), 1440, 720);
 
 	gtk_radio_app = create_gtk_radio_app();
@@ -669,15 +653,6 @@ on_search_matches(GtkEntryCompletion *widget,
 		  GtkTreeIter *iter,
 		  gpointer user_data)
 {
-	/* GeocodeNominatim *geocode_nominatim; */
-	GeocodePlace *place;
-	GeocodeLocation *geocode_location;
-
-	GeocodePlace *place_city, *place_country;
-	GeocodeLocation *location_city;
-	GeocodeLocation *location_country;
-	GeocodeReverse *reverse_city, *reverse_country;
-
 	glong lat, lon;
 	GValue city = {0, };
 	GValue value = {0, };
@@ -707,7 +682,7 @@ on_search_matches(GtkEntryCompletion *widget,
 /* 	geocode_place_set_town (place, town); */
 /* 	geocode_place_set_country(place, country); */
 
-/* 	geocode_nominatim = geocode_nominatim_new ("https://nominatim.gnome.org/", "ole@gnome.org"); */
+/* 	geocode_nominatim = geocode_nominatim_new ("https://nominatim.gnome.org/", "ole@aamot.org"); */
 
 /* 	g_print ("geocode_place_get_town: %s\n", geocode_place_get_town(place)); */
 /* 	g_print ("geocode_place_get_country: %s\n", geocode_place_get_country(place)); */
@@ -759,7 +734,7 @@ main (int argc,
 	/* give the window a 10px wide border */
 	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
 	/* give it the title */
-	gtk_window_set_title (GTK_WINDOW (window), _("GTK Radio"));
+	gtk_window_set_title (GTK_WINDOW (window), _("GTK Radio 548.0 (www.gtkradio.org)"));
 	/* Connect the destroy event of the window with our on_destroy function
 	 * When the window is about to be destroyed we get a notificaiton and
 	 * stop the main GTK loop
@@ -795,7 +770,7 @@ main (int argc,
 
 	license_actor = champlain_view_get_license_actor (view);
 	champlain_license_set_extra_text (license_actor, "Free Internet Radio");
-	champlain_view_center_on (CHAMPLAIN_VIEW (view), 48.8582602, 2.29449905431968);
+	champlain_view_center_on (CHAMPLAIN_VIEW (view), 42.3595302, -83.070678);
 	layer = create_marker_layer (view, &path);
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (path));
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (layer));
